@@ -22,9 +22,3 @@
 """
 Tool to facilitate book digitization with the DIY BookScanner.
 """
-
-import confit
-
-# Lazy-load configuration as a global object
-# NOTE: This is the only global object in this codebase, promised ;-)
-config = confit.LazyConfig('spreads', __name__)
