@@ -1,12 +1,11 @@
 import logging
 import operator
-import os
 
 import wand.api
 import wand.image
 from concurrent import futures
 
-from spreads.plugin import HookPlugin
+from spreads.plugin import HookPlugin, PluginOption
 
 logger = logging.getLogger('spreadsplug.colorcorrect')
 
@@ -16,7 +15,7 @@ def correct_colors(img_path, factors):
     for channel, factor in zip(('red', 'green', 'blue'), factors):
         logger.debug("Correcting {0} channel by {1}"
                      .format(channel, factor))
-        with wand.image.Image(filename=img_path) as img:
+        with wand.image.Image(filename=unicode(img_path)) as img:
             wand.api.libmagick.MagickEvaluateImageChannel(
                 img.wand, wand.image.CHANNELS[channel],
                 wand.image.EVALUATE_OPS.index('multiply'),
@@ -25,36 +24,49 @@ def correct_colors(img_path, factors):
 
 
 class ColorCorrectionPlugin(HookPlugin):
+    __name__ = 'colorcorrect'
+
+    @classmethod
+    def configuration_template(cls):
+        conf = {'true_red': PluginOption(119, "Actual red value for gray"
+                                              "card"),
+                'true_blue': PluginOption(119, "Actual blue value for gray"
+                                               "card"),
+                'true_green': PluginOption(119, "Actual green value for gray"
+                                                "card"),
+                }
+        return conf
+
     def process(self, path):
-        path = os.path.join(path, 'raw')
+        path = path / 'raw'
         logger.debug("Starting color correction...")
         # Get the gray card's RGB values from configuration
-        true_colors = (float(self.config['colorcorrect']['true_red']
+        true_colors = (float(self.config['true_red']
                              .get(int)),
-                       float(self.config['colorcorrect']['true_green']
+                       float(self.config['true_green']
                              .get(int)),
-                       float(self.config['colorcorrect']['true_blue']
+                       float(self.config['true_blue']
                              .get(int))
                        )
         # We assume that the first two images shot were the gray card
-        images = sorted([os.path.join(path, x) for x in os.listdir(path)])
-        factors_left = map(operator.div, true_colors,
-                           self._get_color(images[0]))
-        factors_right = map(operator.div, true_colors,
-                            self._get_color(images[1]))
+        images = sorted(path.iterdir())
+        factors_odd = map(operator.div, true_colors,
+                          self._get_color(images[0]))
+        factors_even = map(operator.div, true_colors,
+                           self._get_color(images[1]))
 
         with futures.ProcessPoolExecutor() as executor:
             # Don't correct the pictures with the gray cards
             for idx, img in enumerate(images[3:]):
                 if not idx % 2:
-                    factors = factors_left
+                    factors = factors_odd
                 else:
-                    factors = factors_right
+                    factors = factors_even
                 executor.submit(correct_colors, img, factors)
 
     def _get_color(self, img_path):
         """ Get average color of image's core 500x500 area. """
-        with wand.image.Image(filename=img_path) as img:
+        with wand.image.Image(filename=unicode(img_path)) as img:
             img.crop(left=img.size[0]/2-250,
                      top=img.size[1]/2-250,
                      width=500, height=500)           # crop rectangle
