@@ -18,17 +18,17 @@ logger = logging.getLogger('spreadsplug.pdfbeads')
 
 
 class PDFBeadsPlugin(HookPlugin):
+    __name__ = 'pdfbeads'
+
     def output(self, path):
         logger.info("Assembling PDF.")
-        img_dir = os.path.join(path, 'done')
-        pdf_file = os.path.join('..', 'out',
-                                "{0}.pdf".format(os.path.basename(path)))
-        img_files = [x
-                     for x in sorted(os.listdir(img_dir))
-                     if os.path.splitext(x)[1].lower() == '.tif']
-        cmd = ["pdfbeads", "-d"] + img_files + ["-o", pdf_file]
+        img_dir = path / 'done'
+        pdf_file = path / 'out' / "{0}.pdf".format(path.name)
+        img_files = [unicode(x.name) for x in sorted(img_dir.glob('*.tif'))]
+        cmd = ["pdfbeads", "-d"] + img_files + ["-o", unicode(pdf_file)]
         logger.debug("Running " + " ".join(cmd))
         # NOTE: pdfbeads only finds *html files for the text layer in the
         #       working directory...
-        os.chdir(img_dir)
-        _ = subprocess.check_output(cmd, stderr=subprocess.STDOUT)
+        os.chdir(unicode(img_dir))
+        output = subprocess.check_output(cmd, stderr=subprocess.STDOUT)
+        logger.debug("Output:\n{0}".format(output))
